%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Einfuehrung in Matlab/Simulink
% 
% Uebung Fachvertiefung Automatisierungs- und Regelungstechnik
% Institut fuer Automatisierungs- und Regelungstechnik 
% Gruppe fuer komplexe dynamische Systeme
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% Diese Musterfile dient zum Erlernen der grafischen Ausgabemoeglichkeiten
% unter Matlab

clear
close all
clc

%% Einfache 2dimensionale plots

% Erzeugen der Daten

x = 0:.1:2*pi;
y = sin(2*x).*exp(-x/pi);


figure(1)   % oeffnet eine Figure-Umgebung

plot(x,y)   % einfacher plot-Befehl

grid on     % Es werden Gitternetzlinien angegeben

% Hinzufuegen eines zweiten Datensatzes

y1 = cos(2*x).*exp(-x/pi);

hold on     % Die dargestellten Elemente werden beibehalten

% Die zweite Kurve wird rot und mit dickerer Strichstaerke dargestellt
plot(x,y1,'red','LineWidth',2) 


legend('Kurve 1','Kurve 2')  % Hinzufuegen einer Legende

axis([0 5 -0.7 1.2])  % Der Darstellungsbereich wird eingegrenzt

% Zusaetzlich ist die Einstellung einer Vielzahl von Parametern im Plot
% moeglich. Einerseits kann dies direkt in der grafischen Oberflaeche
% erfolgen, andererseits mit den Befehlen get und set.

get(gca)  % gca steht fuer 'get current axis'
set(gca, 'FontName', 'Arial', 'FontSize', 14) % Schriftart und -groesse aendern


xlabel('Zeit in s', 'FontName', 'Arial', 'FontSize', 14)       % x-Achsen-Beschriftung
ylabel('Amplitude in V', 'FontName', 'Arial', 'FontSize', 14)  % y-Achsen-Beschriftung
title('Spannungsverlauf', 'FontName', 'Arial', 'FontSize', 14) % Beschriftung des Titels

%% Unterschiedliche Darstellung der Linien

close all

x = 0:.1:2*pi;
y = sin(2*x).*exp(-x/pi);

figure(2) 

plot(x,y,'k.')    % Plot in schwarz mit Punkten
hold on
grid on
plot(x,1.5*y,'bo')    % Plot in blau mit Kreisen
plot(x,2*y,'c*')      % Plot in cyan mit Sternen
plot(x,2.5*y,'g+')    % Plot in gruen mit Kreuzen
plot(x,3*y,'r:')      % Plot in rot punktiert
plot(x,3.5*y,'m--')   % Plot in magenta gestrichelt
plot(x,4*y,'y-.')     % Plot in gelb strichpunktiert


% Weitere Plots

figure(3)

loglog(x,abs(y))      % doppellogarithmischer Plot
grid on

figure(4)

polarplot(0:.1:10,0:.1:10) % Polarplot

% Erstellen von Subplots

figure(5)

subplot(2,1,1)        % Subplot erzeugen
plot(x,y)
grid on
subplot(2,1,2)        % Zugriff auf zweites Fenster
plot(x,2*y)
grid on
subtitle('Dies is ein Sub-Titel');

%% Erstellen von Histogrammen

% erstellen von testdaten
x_normal = randn(10000,1); % Vektor mit 1000 normalverteilten Werten
x_gleich = rand(10000,1); % Vektor mit 1000 gleichverteilten Werten

figure(6)

histogram(x_normal); % Darstellen des Histogramms der normalverteilten Zuvallsvariablen
hold on
histogram(x_gleich,10); % Darstellen des Histogramms der gleichverteilten Zuvallsvariablen, aufgeteilt auf 10 Bins


%% Dreidimensionale Plots

clear
close all
clc

x = 0:0.01:1;

% Darstellung einer Linie im Raum

figure(7)
plot3(sin(x*4*pi),cos(x*4*pi),x,'LineWidth',2)
box on   % Hinzufuegen einer Box
grid on  % Hinzufuegen von Gitternetzlinien

% Darstellung von Flaechen

[xx,yy] = meshgrid(x,x);  % Koordinatenmatrix erzeugen

zz = sin(4*pi*xx).*cos(4*pi*yy).*exp(-xx); % Darzustellende Funktion

% Flaechenplot
figure(8)
surf(xx,yy,zz)
box on
shading interp      %  3D-Flaechen ohne Gitternetzlinien
grid on

% Gitterplot
figure(9)
mesh(xx,yy,zz)
box on
grid on

% 2D Konturplot
figure(10)
contour(xx,yy,zz)
box on
grid on
